@@ -4,12 +4,6 @@
 # license that can be found in the LICENSE file.
 
 ENUM_DIRNAME = "enum"
-FRAGMENT_DIRNAME = "fragment"
 INPUT_DIRNAME = "input"
 
-ENUM_SUFFIX = "enum"
-FRAGMENT_SUFFIX = "fragment"
-INPUT_SUFFIX = "input"
-
-DEFAULT_CONFIG_FNAME = ".gql.json"
 SPACES = " " * 4
